==============
 REANA-Commons
==============

.. image:: https://img.shields.io/pypi/pyversions/reana-commons.svg
      :target: https://pypi.org/pypi/reana-commons

.. image:: https://img.shields.io/travis/reanahub/reana-commons.svg
      :target: https://travis-ci.org/reanahub/reana-commons

.. image:: https://readthedocs.org/projects/docs/badge/?version=latest
      :target: https://reana-commons.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/coveralls/reanahub/reana-commons.svg
      :target: https://coveralls.io/r/reanahub/reana-commons

.. image:: https://badges.gitter.im/Join%20Chat.svg
      :target: https://gitter.im/reanahub/reana?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge

.. image:: https://img.shields.io/github/license/reanahub/reana-commons.svg
      :target: https://github.com/reanahub/reana-commons/blob/master/LICENSE

About
-----

REANA-Commons is a component of the `REANA <http://www.reana.io/>`_ reusable and
reproducible research data analysis platform. It provides common utilities and
schemas shared by the REANA cluster components.

Features
--------

- utility functions for cluster components
- database models and schemas

Useful links
------------

- `documentation <https://reana-commons.readthedocs.io/>`_
- `releases <https://github.com/reanahub/reana-commons/releases>`_
- `known issues <https://github.com/reanahub/reana-commons/issues>`_
- `source code <https://github.com/reanahub/reana-commons>`_

For more information about the REANA reusable analysis platform, please see the
`REANA project <http://www.reana.io>`_ home page and the general `REANA
documentation <http://reana.readthedocs.io/>`_ pages.
